# calisum - A caliap activity scrapper and summarizer

This is a simple Python script that scraps Caliap and allow to you tu summarize your activity using the LLM of your choice.

## Installation

```bash
pip install calisum
```

## Usage



## License
[GPL-3.0](LICENSE.md)
```